# capsulecorp
General python utilities package for working with public cloud services and big data

[![codecov](https://codecov.io/gh/leealessandrini/capsulecorp/branch/main/graph/badge.svg)](https://codecov.io/gh/leealessandrini/capsulecorp)
